@@ -248,18 +248,18 @@ arv_evaluator_token_debug (ArvEvaluatorToken *token, GHashTable *variables)
 	switch (token->token_id) {
 		case ARV_EVALUATOR_TOKEN_VARIABLE:
 			value = g_hash_table_lookup (variables, token->data.name);
-			arv_debug ("evaluator", "(var) %s = %g%s", token->data.name,
-				   value != NULL ? arv_value_get_double (value) : 0,
-				   value != NULL ? "" : " not found");
+			arv_log_evaluator ("(var) %s = %g%s", token->data.name,
+					   value != NULL ? arv_value_get_double (value) : 0,
+					   value != NULL ? "" : " not found");
 			break;
 		case ARV_EVALUATOR_TOKEN_CONSTANT_INT64:
-			arv_debug ("evaluator", "(int64) %Ld", token->data.v_int64);
+			arv_log_evaluator ("(int64) %Ld", token->data.v_int64);
 			break;
 		case ARV_EVALUATOR_TOKEN_CONSTANT_DOUBLE:
-			arv_debug ("evaluator", "(double) %g", token->data.v_double);
+			arv_log_evaluator ("(double) %g", token->data.v_double);
 			break;
 		default:
-			arv_debug ("evaluator", "(operator) %s", arv_evaluator_token_infos[token->token_id].tag);
+			arv_log_evaluator ("(operator) %s", arv_evaluator_token_infos[token->token_id].tag);
 	}
 }
 
@@ -822,9 +822,9 @@ evaluate (GSList *token_stack, GHashTable *variables, gint64 *v_int64, double *v
 		*v_int64 = arv_value_get_int64 (stack);
 
 	if (arv_value_holds_int64 (stack))
-		arv_debug ("evaluator", "[Evaluator::evaluate] Result = (int64) %Ld", arv_value_get_int64 (stack));
+		arv_log_evaluator ("[Evaluator::evaluate] Result = (int64) %Ld", arv_value_get_int64 (stack));
 	else
-		arv_debug ("evaluator", "[Evaluator::evaluate] Result = (double) %g", arv_value_get_double (stack));
+		arv_log_evaluator ("[Evaluator::evaluate] Result = (double) %g", arv_value_get_double (stack));
 
 	return ARV_EVALUATOR_STATUS_SUCCESS;
 CLEANUP:
@@ -847,7 +847,7 @@ parse_expression (char *expression, GSList **rpn_stack)
 	GSList *operator_stack = NULL;
 	GSList *iter;
 
-	arv_debug ("evaluator", expression);
+	arv_log_evaluator (expression);
 
 	/* Dijkstra's "shunting yard" algorithm */
 	/* http://en.wikipedia.org/wiki/Shunting-yard_algorithm */
@@ -940,9 +940,9 @@ arv_evaluator_set_error (GError **error, ArvEvaluatorStatus status)
 		     arv_evaluator_status_strings [MIN (status,
 							G_N_ELEMENTS (arv_evaluator_status_strings)-1)]);
 
-	arv_debug ("evaluator", "[Evaluator::evaluate] Error '%s'",
-		   arv_evaluator_status_strings [MIN (status,
-						      G_N_ELEMENTS (arv_evaluator_status_strings)-1)]);
+	arv_warning_evaluator ("[Evaluator::evaluate] Error '%s'",
+			       arv_evaluator_status_strings [MIN (status,
+								  G_N_ELEMENTS (arv_evaluator_status_strings)-1)]);
 }
 
 double
@@ -953,14 +953,14 @@ arv_evaluator_evaluate_as_double (ArvEvaluator *evaluator, GError **error)
 
 	g_return_val_if_fail (ARV_IS_EVALUATOR (evaluator), 0.0);
 
-	arv_debug ("evaluator", "[Evaluator::evaluate_as_double] Expression = '%s'", 
-		   evaluator->priv->expression);
+	arv_log_evaluator ("[Evaluator::evaluate_as_double] Expression = '%s'", 
+			   evaluator->priv->expression);
 
 	if (evaluator->priv->parsing_status == ARV_EVALUATOR_STATUS_NOT_PARSED) {
 		evaluator->priv->parsing_status = parse_expression (evaluator->priv->expression,
 								    &evaluator->priv->rpn_stack);
-		arv_debug ("evaluator", "[Evaluator::evaluate_as_double] Parsing status = %d",
-			   evaluator->priv->parsing_status);
+		arv_log_evaluator ("[Evaluator::evaluate_as_double] Parsing status = %d",
+				   evaluator->priv->parsing_status);
 	}
 
 	if (evaluator->priv->parsing_status != ARV_EVALUATOR_STATUS_SUCCESS) {
@@ -985,14 +985,14 @@ arv_evaluator_evaluate_as_int64 (ArvEvaluator *evaluator, GError **error)
 
 	g_return_val_if_fail (ARV_IS_EVALUATOR (evaluator), 0.0);
 
-	arv_debug ("evaluator", "[Evaluator::evaluate_as_int64] Expression = '%s'", 
-		   evaluator->priv->expression);
+	arv_log_evaluator ("[Evaluator::evaluate_as_int64] Expression = '%s'", 
+			   evaluator->priv->expression);
 
 	if (evaluator->priv->parsing_status == ARV_EVALUATOR_STATUS_NOT_PARSED) {
 		evaluator->priv->parsing_status = parse_expression (evaluator->priv->expression,
 								    &evaluator->priv->rpn_stack);
-		arv_debug ("evaluator", "[Evaluator::evaluate_as_int64] Parsing status = %d",
-			   evaluator->priv->parsing_status);
+		arv_log_evaluator ("[Evaluator::evaluate_as_int64] Parsing status = %d",
+				   evaluator->priv->parsing_status);
 	}
 
 	if (evaluator->priv->parsing_status != ARV_EVALUATOR_STATUS_SUCCESS) {
@@ -1059,8 +1059,8 @@ arv_evaluator_set_double_variable (ArvEvaluator *evaluator, const char *name, do
 			     g_strdup (name),
 			     arv_value_new_double (v_double));
 
-	arv_debug ("evaluator", "[Evaluator::set_double_variable] %s = %g",
-		   name, v_double);
+	arv_log_evaluator ("[Evaluator::set_double_variable] %s = %g",
+			   name, v_double);
 }
 
 void
@@ -1079,8 +1079,7 @@ arv_evaluator_set_int64_variable (ArvEvaluator *evaluator, const char *name, gin
 			     g_strdup (name),
 			     arv_value_new_int64 (v_int64));
 
-	arv_debug ("evaluator", "[Evaluator::set_int64_variable] %s = %Ld",
-		   name, v_int64);
+	arv_log_evaluator ("[Evaluator::set_int64_variable] %s = %Ld", name, v_int64);
 }
 
 /** 
