@@ -24,23 +24,30 @@
 #define ARV_GVSP_H
 
 #include <arvtypes.h>
+#include <arvdebug.h>
 
 G_BEGIN_DECLS
 
 #define ARV_GVSP_PACKET_INFOS_ID_MASK		0x00ffffff
-#define ARV_GVSP_PACKET_INFOS_TYPE_MASK		0xff000000
-#define ARV_GVSP_PACKET_INFOS_TYPE_POS		24
+#define ARV_GVSP_PACKET_INFOS_CONTENT_TYPE_MASK	0xff000000
+#define ARV_GVSP_PACKET_INFOS_CONTENT_TYPE_POS	24
 
 #define ARV_GVSP_PACKET_PROTOCOL_OVERHEAD	(20 + 8 + 8)		/* IP + UDP + GVSP headers */
 
 typedef enum {
-	ARV_GVSP_PACKET_TYPE_DATA_LEADER = 	0x01,
-	ARV_GVSP_PACKET_TYPE_DATA_TRAILER = 	0x02,
-	ARV_GVSP_PACKET_TYPE_DATA_BLOCK =	0x03
+	ARV_GVSP_PACKET_TYPE_OK =		0x0000,
+	ARV_GVSP_PACKET_TYPE_ERROR =		0x800c
 } ArvGvspPacketType;
 
+typedef enum {
+	ARV_GVSP_CONTENT_TYPE_DATA_LEADER = 	0x01,
+	ARV_GVSP_CONTENT_TYPE_DATA_TRAILER = 	0x02,
+	ARV_GVSP_CONTENT_TYPE_DATA_BLOCK =	0x03
+} ArvGvspContentType;
+
 typedef struct {
-	guint32 frame_id;
+	guint16 packet_type;
+	guint16 frame_id;
 	guint32 packet_infos;
 } __attribute__((__packed__)) ArvGvspHeader;
 
@@ -65,24 +72,30 @@ typedef struct {
 	guint8 data[];
 } ArvGvspPacket;
 
-ArvGvspPacket *		arv_gvsp_packet_new_data_leader		(guint32 frame_id, guint32 packet_id,
+ArvGvspPacket *		arv_gvsp_packet_new_data_leader		(guint16 frame_id, guint32 packet_id,
 								 guint64 timestamp, ArvPixelFormat pixel_format,
 								 guint32 width, guint32 height,
 								 guint32 x_offset, guint32 y_offset,
 								 void *buffer, size_t *buffer_size);
-ArvGvspPacket *		arv_gvsp_packet_new_data_trailer	(guint32 frame_id, guint32 packet_id,
+ArvGvspPacket *		arv_gvsp_packet_new_data_trailer	(guint16 frame_id, guint32 packet_id,
 								 void *buffer, size_t *buffer_size);
-ArvGvspPacket *		arv_gvsp_packet_new_data_block		(guint32 frame_id, guint32 packet_id,
+ArvGvspPacket *		arv_gvsp_packet_new_data_block		(guint16 frame_id, guint32 packet_id,
 								 size_t size, void *data,
 								 void *buffer, size_t *buffer_size);
 char * 			arv_gvsp_packet_to_string 		(const ArvGvspPacket *packet, size_t packet_size);
-void 			arv_gvsp_packet_debug 			(const ArvGvspPacket *packet, size_t packet_size);
-
+void 			arv_gvsp_packet_debug 			(const ArvGvspPacket *packet, size_t packet_size,
+								 ArvDebugLevel level);
 static inline ArvGvspPacketType
-arv_gvsp_packet_get_packet_type	(const ArvGvspPacket *packet)
+arv_gvsp_packet_get_packet_type (const ArvGvspPacket *packet)
 {
-	return (ArvGvspPacketType) ((g_ntohl (packet->header.packet_infos) & ARV_GVSP_PACKET_INFOS_TYPE_MASK) >>
-				    ARV_GVSP_PACKET_INFOS_TYPE_POS);
+	return g_ntohs (packet->header.packet_type);
+}
+
+static inline ArvGvspContentType
+arv_gvsp_packet_get_content_type (const ArvGvspPacket *packet)
+{
+	return (g_ntohl (packet->header.packet_infos) & ARV_GVSP_PACKET_INFOS_CONTENT_TYPE_MASK) >>
+		ARV_GVSP_PACKET_INFOS_CONTENT_TYPE_POS;
 }
 
 static inline guint16
@@ -91,10 +104,10 @@ arv_gvsp_packet_get_packet_id (const ArvGvspPacket *packet)
 	return g_ntohl (packet->header.packet_infos) & ARV_GVSP_PACKET_INFOS_ID_MASK;
 }
 
-static inline guint32
+static inline guint16
 arv_gvsp_packet_get_frame_id (const ArvGvspPacket *packet)
 {
-	return g_ntohl (packet->header.frame_id);
+	return g_ntohs (packet->header.frame_id);
 }
 
 static inline guint32
