@@ -682,8 +682,8 @@ arv_decompress (void *input_buffer, size_t input_size, size_t *output_size)
 		stream.avail_in = MIN (input_size, ARV_DECOMPRESS_CHUNK);
 		stream.next_in = input_buffer;
 
-		arv_debug ("decompress", "[Decompress] Input ptr = 0x%x - Chunk size = %d - %c",
-			   stream.next_in, stream.avail_in, *stream.next_in);
+		arv_debug_misc ("[Decompress] Input ptr = 0x%x - Chunk size = %d - %c",
+				stream.next_in, stream.avail_in, *stream.next_in);
 
 		input_size -= stream.avail_in;
 		input_buffer += stream.avail_in;
@@ -694,19 +694,19 @@ arv_decompress (void *input_buffer, size_t input_size, size_t *output_size)
 			stream.next_out = z_stream_output;
 			result = inflate(&stream, Z_NO_FLUSH);
 			if (result == Z_STREAM_ERROR) {
-				arv_debug ("decompress", "[Decompress] Z_STREAM_ERROR");
+				arv_warning_misc ("[Decompress] Z_STREAM_ERROR");
 				goto CLEANUP;
 			}
 
 			switch (result) {
 				case Z_NEED_DICT:
-					arv_debug ("decompress", "[Decompress] Z_NEED_DICT");
+					arv_warning_misc ("[Decompress] Z_NEED_DICT");
 					goto CLEANUP;
 				case Z_DATA_ERROR:
-					arv_debug ("decompress", "[Decompress] Z_DATA_ERROR");
+					arv_warning_misc ("[Decompress] Z_DATA_ERROR");
 					goto CLEANUP;
 				case Z_MEM_ERROR:
-					arv_debug ("decompress", "[Decompress] Z_MEM_ERROR");
+					arv_warning_misc ("[Decompress] Z_MEM_ERROR");
 					goto CLEANUP;
 			}
 
@@ -721,7 +721,7 @@ arv_decompress (void *input_buffer, size_t input_size, size_t *output_size)
 	inflateEnd(&stream);
 
 	if (result != Z_STREAM_END) {
-		arv_debug ("decompress", "[Decompress] !Z_STREAM_END");
+		arv_warning_misc ("[Decompress] !Z_STREAM_END");
 		g_byte_array_free (output, TRUE);
 		if (output_size != NULL)
 			*output_size = 0;
@@ -834,12 +834,12 @@ arv_pixel_format_to_gst_caps_string (ArvPixelFormat pixel_format)
 			break;
 
 	if (i == G_N_ELEMENTS (arv_gst_caps_infos)) {
-		arv_debug ("gst", "[PixelFormat::to_gst_caps_string] 0x%08x not found", pixel_format);
+		arv_warning_misc ("[PixelFormat::to_gst_caps_string] 0x%08x not found", pixel_format);
 		return NULL;
 	}
 
-	arv_debug ("gst", "[PixelFormat::to_gst_caps_string] 0x%08x -> %s",
-		   pixel_format, arv_gst_caps_infos[i].gst_caps_string);
+	arv_log_misc ("[PixelFormat::to_gst_caps_string] 0x%08x -> %s",
+		      pixel_format, arv_gst_caps_infos[i].gst_caps_string);
 
 	return arv_gst_caps_infos[i].gst_caps_string;
 }
