@@ -338,6 +338,7 @@ arv_viewer_select_camera_cb (GtkComboBox *combo_box, ArvViewer *viewer)
 {
 	GtkTreeIter iter;
 	GtkTreeModel *list_store;
+	GdkWindow *window;
 	GstCaps *caps;
 	GstElement *ffmpegcolorspace;
 	GstElement *ximagesink;
@@ -367,6 +368,12 @@ arv_viewer_select_camera_cb (GtkComboBox *combo_box, ArvViewer *viewer)
 	g_free (camera_id);
 
 	viewer->stream = arv_camera_create_stream (viewer->camera, NULL, NULL);
+	if (viewer->stream == NULL) {
+		g_object_unref (viewer->camera);
+		viewer->camera = NULL;
+		return;
+	}
+
 	if (ARV_IS_GV_STREAM (viewer->stream)) {
 		if (arv_viewer_option_auto_socket_buffer)
 			g_object_set (viewer->stream,
@@ -461,7 +468,8 @@ arv_viewer_select_camera_cb (GtkComboBox *combo_box, ArvViewer *viewer)
 
 	gst_element_set_state (viewer->pipeline, GST_STATE_PLAYING);
 
-	window_xid = GDK_WINDOW_XID (viewer->drawing_area->window);
+	window = gtk_widget_get_window (viewer->drawing_area);
+	window_xid = GDK_WINDOW_XID (window);
 	gst_x_overlay_set_xwindow_id (GST_X_OVERLAY (ximagesink), window_xid);
 
 	g_signal_connect (viewer->stream, "new-buffer", G_CALLBACK (arv_viewer_new_buffer_cb), viewer);
